@@ -83,7 +83,7 @@ act q|
 |;
 
 act q|
-    # 2D data can also easily be accomodated:
+    # 2D data can also easily be accommodated:
 
     # First make a simple image
     $gradient=sequence(40,40);
@@ -133,8 +133,8 @@ act q|
 
   # Now for a more complicated example.
   # First create some data
-  $a=sequence(360)*3.1415/180.;
-  $b=sin($a)*transpose(cos($a));
+  $x=sequence(360)*3.1415/180.;
+  $y=sin($x)*transpose(cos($x));
 
   # Make a piddle with the wanted contours
   $contours=pdl [0.1,0.5,1.0];
@@ -142,13 +142,13 @@ act q|
   $labels=['A', 'B', 'C'];
   # Create a contour map of the data - note that we can set the colour of
   # the labels.
-  cont($b, {CONTOURS=>$contours, linest=>'DASHED',
+  cont($y, {CONTOURS=>$contours, linest=>'DASHED',
 	    LINEWIDTH=>3, COLOR=>2, LABELCOL=>4});
   hold;
 
   pgqlw($linewidth);
 
-  points $a->slice('0:-1:4')*180./3.1415;
+  points $x->slice('0:-1:4')*180./3.1415;
   release;
 |;
 
@@ -156,10 +156,10 @@ act q|
   #
   # More examples of changing the plot defaults
   # 
-  $a = 1+sequence(10);
-  $b = $a*2;
+  $x = 1+sequence(10);
+  $y = $x*2;
   $bord_opt = { TYPE => 'RELATIVE', VALUE => 0.1 };
-  line log10($a), $b, { AXIS => 'LOGX', BORDER => $bord_opt };
+  line log10($x), $y, { AXIS => 'LOGX', BORDER => $bord_opt };
 |;
 
 act q|
